==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/rdetect/translations/rdetect_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Plugin Deteksi Volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Tentang Plugin Deteksi Volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Plugin Deteksi Volume Yang Dapat Dibuang Qmmp</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Plugin ini menyediakan deteksi volume yang dapat dibuang</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Tambah CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Tambah Volume &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Pengaturan Plugin Deteksi Volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Deteksi Audio CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Tambah track ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Buang track dari daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Deteksi Perangkat Dapat-dilepas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Tambah file ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Buang file dari daftarmain secara otomatis</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/General/rdetect/translations/rdetect_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Plugin Deteksi Volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Tentang Plugin Deteksi Volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Plugin Deteksi Volume Yang Dapat Dibuang Qmmp</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Plugin ini menyediakan deteksi volume yang dapat dibuang</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RDetectSettingsDialog</name>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation type="unfinished">Pengaturan Plugin Deteksi Volume</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation type="unfinished">Deteksi Audio CD</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation type="unfinished">Tambah track ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation type="unfinished">Buang track dari daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation type="unfinished">Deteksi Perangkat Dapat-dilepas</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation type="unfinished">Tambah file ke daftarmain secara otomatis</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation type="unfinished">Buang file dari daftarmain secara otomatis</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Tambah CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Tambah Volume &quot;%1&quot;</translation>
    </message>
</context>
</TS>
